@@ -3,12 +3,8 @@ use lib "$ENV{HOME}/perl";
 
 use X3D;
 $X3DGenerator::AllFields = 1;
-
-my $scene = Browser->createX3DFromString(<DATA>);
-Browser->replaceWorld( $scene );
-
-printf "%s\n", $scene->rootNodes->[0]->getReferenceCount;
-
+Browser->createX3DFromString(<DATA>);
+#Browser->replaceWorld( Browser->createX3DFromString(<DATA>) );
 Gtk2->main;
 
 printf "%s\n", Browser;
@@ -21,7 +17,6 @@ COMPONENT Gtk2 1
 META "name" "Outliner"
 META "version" "0.01"
 
-MetadataDouble {},
 DEF Gtk2Main Gtk2Main {},
 DEF OutlineEditorWindow Gtk2Window {
   title "OutlineEditor"
@@ -33,15 +28,11 @@ DEF OutlineEditorWindow Gtk2Window {
   children Gtk2OutlineEditor {
     title "Outline"
 	 children [
-		MetadataDouble {},
 		DEF Double MetadataDouble {},
 		MetadataFloat {},
 		DEF Set MetadataSet {
-			metadata MetadataFloat {}
 			value [
-				DEF Float0 MetadataFloat {},
-				DEF Float1 MetadataFloat {},
-				DEF Float2 MetadataFloat {},
+				MetadataFloat {},
 			]
 		},
 		MetadataString {},
