@@ -7,14 +7,11 @@ use rlib "X3D/Components/Gtk2/Nodes";
 
 #Abstract node types
 use X3DGtk2Bin;
-use X3DGtk2Container;
 use X3DGtk2Node;
-use X3DGtk2Widget;
 
 #Node set
 use Gtk2Main;
 use Gtk2OutlineEditor;
-use Gtk2OutlineEditor;
 use Gtk2Window;
 
 1;
