@@ -6,8 +6,6 @@ use rlib "../";
 
 use base qw(X3DGtk2Widget);
 
-use X3DError debug => 1;
-
 use X3DConstants;
 use Gtk2OutlineEditor::TreeView;
 
@@ -33,11 +31,6 @@ sub create {
 	$this->setWidget($vbox);
 }
 
-sub setBrowser {
-	my ($this, $browser) = @_;
-	$this->{treeView}->setBrowser($browser);
-}
-
 sub initialize {
 	my ($this) = @_;
 	$this->_children($this->children);
