@@ -5,7 +5,6 @@ no strict 'refs';
 
 use rlib "../";
 
-use Hash::NoRef;
 use Scalar::Util;
 use X3DGenerator;
 use X3DError;
@@ -22,35 +21,22 @@ sub new {
 
 sub getId { Scalar::Util::refaddr(shift) }
 
-sub clone {
-	my $this   = shift;
-	my $scalar = $this->new( $this->getValue );
-	return $scalar;
-}
-
-sub copy {
-	my $this   = shift;
-	my $scalar = $this->new( $this->getValue );
-	return $scalar;
-}
-
 sub setValue {
 	my $this = shift;
 	$this->{value} = shift;
 }
 
-sub getValue { $_[0]->{value} }
+sub getValue { return (shift)->{value} }
 
 sub getReferenceCount {
 	my $this = shift;
 	return Hash::NoRef::SvREFCNT( $this->{value} );
 }
 
-sub toString {
-	return $_[0]->getValue;
+sub DESTROY {
+	my $this = shift;
+	0;
 }
 
-sub DESTROY { 0 }
-
 1;
 __END__
